==> volcano-model-v1beta1-6.5.0-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueListFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface QueueListFluent<A extends QueueListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Queue item);
  public A setToItems(Integer index,Queue item);
  public A addToItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public A addAllToItems(Collection<Queue> items);
  public A removeFromItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public A removeAllFromItems(Collection<Queue> items);
  public A removeMatchingFromItems(Predicate<QueueBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Queue> getItems();
  public List<Queue> buildItems();
  public Queue buildItem(Integer index);
  public Queue buildFirstItem();
  public Queue buildLastItem();
  public Queue buildMatchingItem(Predicate<QueueBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<QueueBuilder> predicate);
  public A withItems(List<Queue> items);
  public A withItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public Boolean hasItems();
  public QueueListFluent.ItemsNested<A> addNewItem();
  public QueueListFluent.ItemsNested<A> addNewItemLike(Queue item);
  public QueueListFluent.ItemsNested<A> setNewItemLike(Integer index,Queue item);
  public QueueListFluent.ItemsNested<A> editItem(Integer index);
  public QueueListFluent.ItemsNested<A> editFirstItem();
  public QueueListFluent.ItemsNested<A> editLastItem();
  public QueueListFluent.ItemsNested<A> editMatchingItem(Predicate<QueueBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,QueueFluent<QueueListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> volcano-model-v1beta1-6.7.1-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueListFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface QueueListFluent<A extends QueueListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Queue item);
  public A setToItems(int index,Queue item);
  public A addToItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public A addAllToItems(Collection<Queue> items);
  public A removeFromItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public A removeAllFromItems(Collection<Queue> items);
  public A removeMatchingFromItems(Predicate<QueueBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Queue> getItems();
  public List<Queue> buildItems();
  public Queue buildItem(int index);
  public Queue buildFirstItem();
  public Queue buildLastItem();
  public Queue buildMatchingItem(Predicate<QueueBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<QueueBuilder> predicate);
  public A withItems(List<Queue> items);
  public A withItems(io.fabric8.volcano.scheduling.v1beta1.Queue... items);
  public Boolean hasItems();
  public QueueListFluent.ItemsNested<A> addNewItem();
  public QueueListFluent.ItemsNested<A> addNewItemLike(Queue item);
  public QueueListFluent.ItemsNested<A> setNewItemLike(int index,Queue item);
  public QueueListFluent.ItemsNested<A> editItem(int index);
  public QueueListFluent.ItemsNested<A> editFirstItem();
  public QueueListFluent.ItemsNested<A> editLastItem();
  public QueueListFluent.ItemsNested<A> editMatchingItem(Predicate<QueueBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,QueueFluent<QueueListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
